@@ -22,7 +22,7 @@ Test::OpenTracing::Interface::SpanContext - compliance testing
 use strict;
 use warnings;
 
-our $VERSION = 'v0.20.1';
+our $VERSION = 'v0.21.0';
 
 
 use Test::OpenTracing::Interface;
@@ -65,7 +65,9 @@ sub can_all_ok {
         interface_name      => 'SpanContext',
         interface_methods   => [
             'get_baggage_item',
+            'get_baggage_items',
             'with_baggage_item',
+            'with_baggage_items',
         ],
         maybe
         message             => $message,
